<?php
/*
Plugin Name: FG Testimonials
Description: Allow you to create Beautiful Testimonials with wide range of settings to have full control over plugin.
Version: 1.5.7
Author: FuduGo
Author URI: http://fudugo.com/
Text Domain: fg-testimonials
Domain Path: /languages
*/
?>
<?php 

define( 'FGTS_DIR',  plugin_dir_path( __FILE__ ) );
define( 'FGTS_URI', plugin_dir_url( __FILE__ ) );
define( 'FGTS_BASENAME', plugin_basename(__FILE__) );
//define( 'fgts_BaseName', plugin_basename(__FILE__) );

class fgtsTestimonials
{
    function __construct(){      
        
        add_action('init', array($this, 'fgts_include_file'));
        //run activation steps
        register_activation_hook( __FILE__, array($this, 'fgts_testimonial_activation' ) );
        //run deactivation steps
        register_deactivation_hook( __FILE__, array($this, 'fgts_testimonial_deactivation' ) );
        //setup custom post type
        add_action( 'init', array($this, 'fgts_create_posttype_func' ) );   

        if ( ! function_exists( 'fgts_add_script_style' ) ) {
            add_action( 'wp_enqueue_scripts', array($this, 'fgts_add_script_style' ), 10 );
        }
        add_action('admin_enqueue_scripts', array($this, 'fgts_admin_style' ));
        add_filter( 'widget_text', 'do_shortcode' ); // to work shortcode in custom html widget. 
    }
    
    function fgts_include_file() {

        include FGTS_DIR .'include/fg-testimonial-meta.php';
        include FGTS_DIR .'include/fg-testimonial-shortcode.php';
        include FGTS_DIR .'include/fg-setting/fg-settings.php';
    }
    
    function fgts_testimonial_activation() {        
        // trigger our function that registers the custom post type
        $this->fgts_create_posttype_func();

        // clear the permalinks after the post type has been registered
        flush_rewrite_rules();
    }
    

    function fgts_testimonial_deactivation() {
        // unregister the post type, so the rules are no longer in memory
        unregister_post_type( 'fgts_post_type' );
        // clear the permalinks to remove our post type's rules from the database
        flush_rewrite_rules();
    }  

    /*Starts Post Type*/
    function fgts_create_posttype_func() {
        
        register_post_type( 'fgts_post_type',
            array(
                'labels'       => array(
                    'name'       => __( 'FG Testimonials' ),
                    'slug' => 'fg_testimonial',
                    'all_items' => __( 'All' ),
                ),
                'public'       => true,
                'hierarchical' => true,
                'has_archive'  => true,
                'supports'     => array(
                    'title',
                    'editor',                    
                    'thumbnail',
                ), 
                'taxonomies'   => array(
                    'fg-category'
                ),
                'menu_icon' => 'dashicons-format-quote',
            )
        );
        register_taxonomy(
            'fgts-category', //category name display as taxonomy=team-category in category url
            'fgts_post_type', //custom post_type
            array(
                'label' => __( 'Categories' ),
                'rewrite' => array( 'slug' => 'fgts-category' ),
                'hierarchical' => true,
                'show_admin_column' => true, //adding the category to the admin column for a custom post type
            )
        );
        
    }

    /*Ends Post Type*/      
    function fgts_add_script_style() {
        /* Register & Enqueue Styles. */ 
        wp_register_style( 'fgts-style', FGTS_URI.'css/fg-testimonial.css' );
        wp_enqueue_style( 'fgts-style' );        
        wp_register_style( 'fgts-style1', FGTS_URI. 'css/owl.carousel.min.css' );
        wp_enqueue_style( 'fgts-style1' );
        wp_register_style( 'fgts-style2', FGTS_URI.'css/owl.theme.default.min.css' );
        wp_enqueue_style( 'fgts-style2' );
        wp_register_style( 'fgts-style3', FGTS_URI.'css/font-awesome.min.css' );
        wp_enqueue_style( 'fgts-style3' );

        /* Register & Enqueue scripts. */       
        wp_register_script( 'fgts-script2', FGTS_URI.'js/owl.carousel.min.js', '', '', TRUE );
        wp_enqueue_script( 'fgts-script2'); 
        wp_register_script( 'fgts-script3', FGTS_URI.'js/fg-testimonial.js', '', '', TRUE);
        //wp_enqueue_script( 'fgts-script3');

        $fgts_arr_data = $this->fgts_senddata_to_js();
        wp_localize_script( 'fgts-script3', 'fgts_settings', $fgts_arr_data);
        // Enqueued script with localized data.
        wp_enqueue_script( 'fgts-script3' );
    }

    function fgts_admin_style() {
        wp_enqueue_style('admin-styles', FGTS_URI.'css/custom-admin.css');
    } 

    function fgts_senddata_to_js(){

        $fgts_numofslides = get_option('fgts_numofslide_desktop');
        $fgts_numofboxes_dekstop = !empty($fgts_numofslides) ? $fgts_numofslides : 1 ;

        $fgts_numofslide_tablet = get_option('fgts_numofslide_tablet');
        $fgts_numofboxes_tablet = !empty($fgts_numofslide_tablet) ? $fgts_numofslide_tablet : 1 ;

        $fgts_numofslide_mobile = get_option('fgts_numofslide_mobile');
        $fgts_numofboxes_mobile = !empty($fgts_numofslide_mobile) ? $fgts_numofslide_mobile : 1 ;

        $fgts_controls_nav = get_option('fgts_controls_nav');
        $fgts_nav_arrow = !empty($fgts_controls_nav) ? $fgts_controls_nav : false ;

        $fgts_control_dots = get_option('fgts_control_dots');
        $fgts_dots = !empty($fgts_control_dots) ? $fgts_control_dots : false ;

        $fgts_loop_set = get_option('fgts_loop_set');
        $fgts_loop_btn = !empty($fgts_loop_set) ? $fgts_loop_set : false ;

        $fgts_autoplay = get_option('fgts_autoplay');
        $fgts_autoplay_btn = !empty($fgts_autoplay) ? $fgts_autoplay : false ;

        $fgts_autoplayhover = get_option('fgts_autoplayhover');
        $fgts_autoplayhover_btn = !empty($fgts_autoplayhover) ? $fgts_autoplayhover : 'false' ;

        $fgts_numof_smartspeed = get_option('fgts_numof_smartspeed');
        $numof_smartspeed = !empty($fgts_numof_smartspeed) ? $fgts_numof_smartspeed : 250 ;

        $initialized_data = array('numofboxes_dekstop'=>$fgts_numofboxes_dekstop, 'numofboxes_tablet'=>$fgts_numofboxes_tablet, 'numofboxes_mobile'=>$fgts_numofboxes_mobile, 'nav_arrow'=>$fgts_nav_arrow, 'dots_pager'=>$fgts_dots, 'autoplay_btn'=>$fgts_autoplay_btn, 'smartspeed'=>$numof_smartspeed, 'loop_setting'=>$fgts_loop_btn, 'autoplayhover_pause'=>$fgts_autoplayhover_btn);

        $fgts_arr_data = apply_filters("fgts_testimonial_settings", $initialized_data);

        return $fgts_arr_data;        
    }   

}

// create an instance of fgtsTestimonials
if ( !isset($fgts_testimonials) ) {
    $fgts_testimonials = new fgtsTestimonials();
}
